@@ -23,7 +23,7 @@ try:
 except ImportError:  # pragma: no cover
     pa = None  # pragma: no cover
 
-from medvedi.accelerators import in1d_str, is_not_null, is_null, unordered_unique
+from medvedi.accelerators import array_of_objects, in1d_str, is_not_null, is_null, unordered_unique
 from medvedi.io import deserialize_df, serialize_df
 from medvedi.merge_to_str import merge_to_str, mergeable_dtype_kinds
 from medvedi.pure_static import PureStaticDataFrameMethods
@@ -81,6 +81,8 @@ class Index:
 
     def _is_monotonic(self, op: str) -> bool:
         """Check whether the index is sorted."""
+        if len(self._parent) <= 1:
+            return True
         index = self._parent._index
         columns = self._parent._columns
         last_level = len(index) - 1
@@ -92,8 +94,8 @@ class Index:
             else:
                 indexes = np.arange(len(values) - 1)
             if getattr(values[indexes + 1], op)(values[indexes]).all():
-                if i == last_level or len(values) == 1:
-                    return True
+                if i == last_level:
+                    break
                 if mask is None:
                     mask = np.ones(len(values) - 1, dtype=bool)
                 zero_mask = values[indexes + 1] == values[indexes]
@@ -399,9 +401,15 @@ class DataFrame(metaclass=PureStaticDataFrameMethods):
         """
         if np.isscalar(value) or value is None:
             if key in self._columns:
-                self._columns[key][:] = value
-                return
-            value = np.full(len(self), value)
+                dtype = self._columns[key].dtype
+                if dtype.kind == "S" or dtype.kind == "U":
+                    dtype = f"{dtype.kind}{len(value)}"
+            else:
+                dtype = None
+            if dtype == object:
+                value = array_of_objects(len(self), value)
+            else:
+                value = np.full(len(self), value, dtype=dtype)
         else:
             value = np.atleast_1d(np.squeeze(np.asarray(value)))
         if value.ndim != 1:
